@@ -34,6 +34,7 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDesktopWidget>
+#include <QAction>
 #include <QApplication>
 #include <QTextDocument>
 
@@ -105,7 +106,7 @@ void KMixDockWidget::controlsChange(int changeType)
 //      _kmixMainWindow->updateDocking();
 //      _kmixMainWindow->saveConfig();
       refreshVolumeLevels();
-      actionCollection()->action(QLatin1String("select_master"))->setEnabled(Mixer::getGlobalMasterMixer() != 0);
+      findAction("select_master")->setEnabled(Mixer::getGlobalMasterMixer() != 0);
       break;
 
     case ControlChangeType::Volume:
@@ -117,6 +118,24 @@ void KMixDockWidget::controlsChange(int changeType)
   }
 }
 
+QAction* KMixDockWidget::findAction(const char* actionName)
+{
+#ifdef X_KMIX_KF5_BUILD
+	QList<QAction*> actions = actionCollection();
+	int size = actions.size();
+	for (int i=0; i<size; ++i)
+	{
+		QAction* action = actions.at(i);
+        if (action->data().toString() == QString::fromUtf8(actionName))
+			return action;
+	}
+    qWarning() << "ACTION" << actionName << "NOT FOUND!";
+    return Q_NULLPTR;
+#else
+	return actionCollection()->action(QLatin1String(actionName));
+#endif
+}
+
 /**
  * Updates all visual parts of the volume, namely tooltip and pixmap
  */
@@ -132,22 +151,34 @@ void KMixDockWidget::refreshVolumeLevels()
 void KMixDockWidget::createMenuActions()
 {
     QMenu *menu = contextMenu();
-    if ( menu == 0)
-    	return; // We do not use a menu
+    if (!menu)
+        return; // We do not use a menu
 
     shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
     if ( md.get() != 0 && md->hasMuteSwitch() ) {
         // Put "Mute" selector in context menu
-        KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
-        updateDockMuteAction(action);
-        action->setText( i18n( "M&ute" ) );
+#ifdef X_KMIX_KF5_BUILD
+        KToggleAction *action = new KToggleAction(i18n("M&ute"), this);
+        action->setData("dock_mute");
+        addAction("dock_mute", action);
+#else
+    	KToggleAction *action = actionCollection()->add<KToggleAction>( "dock_mute" );
+        action->setText( i18n("M&ute") );
+#endif
+    	updateDockMuteAction(action);
         connect(action, SIGNAL(triggered(bool)), SLOT(dockMute()));
         menu->addAction( action );
     }
 
     // Put "Select Master Channel" dialog in context menu
+#ifdef X_KMIX_KF5_BUILD
+    QAction *action = new QAction(i18n("Select Master Channel..."), this);
+    action->setData("select_master");
+    addAction("select_master", action);
+#else
     QAction *action = actionCollection()->addAction( "select_master" );
     action->setText( i18n("Select Master Channel...") );
+#endif
     action->setEnabled(Mixer::getGlobalMasterMixer() != 0);
     connect(action, SIGNAL(triggered(bool)), _kmixMainWindow, SLOT(slotSelectMaster()));
     menu->addAction( action );
@@ -161,6 +192,7 @@ KMixDockWidget::setVolumeTip()
 {
     shared_ptr<MixDevice> md = Mixer::getGlobalMasterMD();
     QString tip;
+    QString subTip;
     int virtualToolTipValue = 0;
 
     if ( md.get() == 0 )
@@ -176,8 +208,8 @@ KMixDockWidget::setVolumeTip()
         tip += "<font size=\"+1\">" + i18n( "Volume at %1%", val ) + "</font>";
         if ( md->isMuted() )
             tip += i18n( " (Muted)" );
-        tip += QString( "<br/><font size=\"-1\">%1<br/>%2</font>" )
-            .arg( Qt::escape(md->mixer()->readableName()) ).arg( Qt::escape(md->readableName()) );
+        subTip = QString( "%1<br/>%2" )
+                 .arg( Qt::escape(md->mixer()->readableName()) ).arg( Qt::escape(md->readableName()) );
 
         // create a new "virtual" value. With that we see "volume changes" as well as "muted changes"
         virtualToolTipValue = val;
@@ -190,6 +222,7 @@ KMixDockWidget::setVolumeTip()
     {
         // changed (or completely new tooltip)
         setToolTipTitle(tip);
+        setToolTipSubTitle(subTip);
     }
     _oldToolTipValue = virtualToolTipValue;
 }
@@ -230,13 +263,13 @@ void KMixDockWidget::updatePixmap()
 }
 
 /**
- * Called whenever the icon gets "activated". Unusally whn its clicked.
+ * Called whenever the icon gets "activated". Usually when its clicked.
  * @overload
  * @param pos
  */
 void KMixDockWidget::activate(const QPoint &pos)
 {
-	QWidget* dockAreaPopup = _dockAreaPopupMenuWrapper; // TODO Refactor to use _referenceWidget directly
+	QWidget* dockAreaPopup = _dockAreaPopupMenuWrapper; // TODO Refactor to use _dockAreaPopupMenuWrapper directly
 	if (dockAreaPopup->isVisible())
 	{
 		dockAreaPopup->hide();
@@ -268,33 +301,33 @@ void KMixDockWidget::activate(const QPoint &pos)
 	// Now handle Multihead displays. And also make sure that the dialog is not
 	// moved out-of-the screen on the right (see Bug 101742).
 	const QDesktopWidget* vdesktop = QApplication::desktop();
-	const QRect& vScreenSize = vdesktop->availableGeometry(dockAreaPopup);
+	int screenNumber = vdesktop->screenNumber(pos);
+	const QRect& vScreenSize = vdesktop->availableGeometry(screenNumber);
 
 	if ((x + dockAreaPopup->width()) > (vScreenSize.width() + vScreenSize.x()))
 	{
 		// move horizontally, so that it is completely visible
 		x = vScreenSize.width() + vScreenSize.x() - dockAreaPopup->width() - 1;
-		kDebug()
-		<< "Multihead: (case 1) moving to" << vScreenSize.x() << "," << vScreenSize.y();
+		kDebug() << "Multihead: (case 1) moving to" << x << "," << y;
 	}
 	else if (x < vScreenSize.x())
 	{
 		// horizontally out-of bound
 		x = vScreenSize.x();
-		kDebug() << "Multihead: (case 2) moving to" << vScreenSize.x() << "," << vScreenSize.y();
+		kDebug() << "Multihead: (case 2) moving to" << x << "," << y;
 	}
 
 	if ((y + dockAreaPopup->height()) > (vScreenSize.height() + vScreenSize.y()))
 	{
 		// move horizontally, so that it is completely visible
 		y = vScreenSize.height() + vScreenSize.y() - dockAreaPopup->height() - 1;
-		kDebug() << "Multihead: (case 3) moving to" << vScreenSize.x() << "," << vScreenSize.y();
+		kDebug() << "Multihead: (case 3) moving to" << x << "," << y;
 	}
 	else if (y < vScreenSize.y())
 	{
 		// horizontally out-of bound
 		y = vScreenSize.y();
-		kDebug() << "Multihead: (case 4) moving to" << vScreenSize.x() << "," << vScreenSize.y();
+		kDebug() << "Multihead: (case 4) moving to" << x << "," << y;
 	}
 
 
@@ -359,17 +392,19 @@ KMixDockWidget::dockMute()
 bool KMixDockWidget::onlyHaveOneMouseButtonAction()
 {
 	QDBusConnection connection = QDBusConnection::sessionBus();
-    bool unityIsRunnig = (connection.interface()->isServiceRegistered("com.canonical.Unity.Panel.Service"));
+    bool unityIsRunning = (connection.interface()->isServiceRegistered("com.canonical.Unity.Panel.Service"));
     // Possibly implement other detectors, like for Gnome 3 or Gnome 2
-    return unityIsRunnig;
+    return unityIsRunning;
 
 }
 
 void KMixDockWidget::contextMenuAboutToShow()
 {
     // Enable/Disable "Muted" menu item
-    KToggleAction *dockMuteAction = static_cast<KToggleAction*>(actionCollection()->action("dock_mute"));
-    updateDockMuteAction(dockMuteAction);
+    KToggleAction *dockMuteAction = static_cast<KToggleAction*>(findAction("dock_mute"));
+    qDebug() << "DOCK MUTE" << dockMuteAction;
+    if (dockMuteAction)
+        updateDockMuteAction(dockMuteAction);
 }
 
 void KMixDockWidget::updateDockMuteAction ( KToggleAction* dockMuteAction )
