@@ -39,7 +39,7 @@
 #include <QMouseEvent>
 #include <QLabel>
 #include <qpixmap.h>
-#include <qwmatrix.h>
+//#include <qwmatrix.h>
 #include <QBoxLayout>
 
 #include "core/ControlManager.h"
@@ -103,12 +103,12 @@ void MDWSlider::createActions()
     taction->setText( i18n("&Split Channels") );
     connect( taction, SIGNAL(triggered(bool)), SLOT(toggleStereoLinked()) );
 
-    KAction *action;
-    if ( ! m_mixdevice->mixer()->isDynamic() ) {
-        action = _mdwActions->add<KToggleAction>( "hide" );
-        action->setText( i18n("&Hide") );
-        connect( action, SIGNAL(triggered(bool)), SLOT(setDisabled(bool)) );
-    }
+//    KAction *action;
+//    if ( ! m_mixdevice->mixer()->isDynamic() ) {
+//        action = _mdwActions->add<KToggleAction>( "hide" );
+//        action->setText( i18n("&Hide") );
+//        connect( action, SIGNAL(triggered(bool)), SLOT(setDisabled(bool)) );
+//    }
 
     if( m_mixdevice->hasMuteSwitch() )
     {
@@ -128,17 +128,17 @@ void MDWSlider::createActions()
         connect( m_moveMenu, SIGNAL(aboutToShow()), SLOT(showMoveMenu()) );
     }
 
-    action = _mdwActions->addAction( "keys" );
-    action->setText( i18n("C&onfigure Shortcuts...") );
-    connect( action, SIGNAL(triggered(bool)), SLOT(defineKeys()) );
+    QAction* qaction = _mdwActions->addAction( "keys" );
+    qaction->setText( i18n("C&onfigure Shortcuts...") );
+    connect( qaction, SIGNAL(triggered(bool)), SLOT(defineKeys()) );
 }
 
-void MDWSlider::addGlobalShortcut(KAction* action, const QString& label, bool dynamicControl)
+void MDWSlider::addGlobalShortcut(QAction* qaction, const QString& label, bool dynamicControl)
 {
 	QString finalLabel(label);
 	finalLabel += " - " + mixDevice()->readableName() + ", " + mixDevice()->mixer()->readableName();
 
-	action->setText(label);
+	qaction->setText(label);
 	if (!dynamicControl)
 	{
 		// virtual / dynamic controls won't get shortcuts
@@ -147,7 +147,12 @@ void MDWSlider::addGlobalShortcut(KAction* action, const QString& label, bool dy
 		//     #endif
 		//   b->enableGlobalShortcut();
 		// enableGlobalShortcut() is not there => use workaround
-		action->setGlobalShortcut(dummyShortcut);
+#ifdef X_KMIX_KF5_BUILD
+		KGlobalAccel::setGlobalShortcut(qaction, dummyShortcut);
+#else
+		KAction* kaction = (KAction*)qaction;
+		kaction->setGlobalShortcut(dummyShortcut);
+#endif
 	}
 }
 
@@ -160,28 +165,32 @@ void MDWSlider::createShortcutActions()
         I work around this by using a text with setText() that is unique, but still readable to the user.
     */
     QString actionSuffix  = QString(" - %1, %2").arg( mixDevice()->readableName() ).arg( mixDevice()->mixer()->readableName() );
-    KAction *b;
+#ifdef X_KMIX_KF5_BUILD
+    QAction *bi, *bd, *bm;
+#else
+    KAction *bi, *bd, *bm;
+#endif
 
     // -1- INCREASE VOLUME SHORTCUT -----------------------------------------
-    b = _mdwPopupActions->addAction( QString("Increase volume %1").arg( actionSuffix ) );
+    bi = _mdwPopupActions->addAction( QString("Increase volume %1").arg( actionSuffix ) );
     QString increaseVolumeName = i18n( "Increase Volume" );
-	addGlobalShortcut(b, increaseVolumeName, dynamicControl);
+	addGlobalShortcut(bi, increaseVolumeName, dynamicControl);
    	if ( ! dynamicControl )
-        connect( b, SIGNAL(triggered(bool)), SLOT(increaseVolume()) );
+        connect( bi, SIGNAL(triggered(bool)), SLOT(increaseVolume()) );
 
     // -2- DECREASE VOLUME SHORTCUT -----------------------------------------
-    b = _mdwPopupActions->addAction( QString("Decrease volume %1").arg( actionSuffix ) );
+    bd = _mdwPopupActions->addAction( QString("Decrease volume %1").arg( actionSuffix ) );
     QString decreaseVolumeName = i18n( "Decrease Volume" );
-	addGlobalShortcut(b, decreaseVolumeName, dynamicControl);
+	addGlobalShortcut(bd, decreaseVolumeName, dynamicControl);
 	if ( ! dynamicControl )
-		connect(b, SIGNAL(triggered(bool)), SLOT(decreaseVolume()));
+		connect(bd, SIGNAL(triggered(bool)), SLOT(decreaseVolume()));
 
     // -3- MUTE VOLUME SHORTCUT -----------------------------------------
-    b = _mdwPopupActions->addAction( QString("Toggle mute %1").arg( actionSuffix ) );
+    bm = _mdwPopupActions->addAction( QString("Toggle mute %1").arg( actionSuffix ) );
     QString muteVolumeName = i18n( "Toggle Mute" );
-	addGlobalShortcut(b, muteVolumeName, dynamicControl);
+	addGlobalShortcut(bm, muteVolumeName, dynamicControl);
    	if ( ! dynamicControl )
-        connect( b, SIGNAL(triggered(bool)), SLOT(toggleMuted()) );
+        connect( bm, SIGNAL(triggered(bool)), SLOT(toggleMuted()) );
 
 }
 
@@ -223,11 +232,11 @@ int MDWSlider::labelExtentHint() const
  * If a label from another widget has more lines than this widget, then a spacer is added under the label
  */
 void MDWSlider::setLabelExtent(int extent) {
-	if ( _orientation == Qt::Vertical ) {
-		if ( labelExtentHint() < extent )
-			labelSpacer->setFixedHeight( extent - labelExtentHint() );
-		else
-			labelSpacer->setFixedHeight(0);
+	if ( _orientation == Qt::Vertical )
+	{
+		int extentHint = labelExtentHint();
+		int spacerHeight = (extent > extentHint) ? extent - extentHint : 0;
+		labelSpacer->setFixedHeight(spacerHeight);
 	}
 }
 
@@ -306,7 +315,9 @@ void MDWSlider::guiAddMuteButton(bool wantsMuteButton, Qt::Alignment alignment,
 		m_qcb = new QToolButton(this);
 		m_qcb->setAutoRaise(true);
 		m_qcb->setCheckable(false);
-		m_qcb->setIcon(QIcon(loadIcon("audio-volume-muted")));
+		//m_qcb->setIcon(QIcon(loadIcon("audio-volume-muted")));
+		setIcon("audio-volume-muted", m_qcb);
+		//setIcon("audio-volume-mutd", m_qcb);
 		layoutForMuteButton->addWidget(m_qcb, 0, alignment);
 		m_qcb->installEventFilter(this);
 		connect(m_qcb, SIGNAL(clicked(bool)), this, SLOT(toggleMuted()));
@@ -525,7 +536,7 @@ void MDWSlider::addMediaControls(QBoxLayout* volLayout)
 QToolButton* MDWSlider::addMediaButton(QString iconName, QLayout* layout, QWidget *parent)
 {
 	QToolButton *lbl = new QToolButton(parent);
-	lbl->setIconSize(QSize(22,22));
+	lbl->setIconSize(QSize(IconSize(KIconLoader::Toolbar),IconSize(KIconLoader::Toolbar)));
 	lbl->setAutoRaise(true);
 	lbl->setCheckable(false);
 	
@@ -682,9 +693,9 @@ QWidget* MDWSlider::createLabel(QWidget* parent, QString& label, QBoxLayout *lay
 }
 
 
-QPixmap MDWSlider::loadIcon( QString filename )
+QPixmap MDWSlider::loadIcon( QString filename, KIconLoader::Group group )
 {
-	return KIconLoader::global()->loadIcon( filename, KIconLoader::Small, KIconLoader::SizeSmallMedium );
+	return KIconLoader::global()->loadIcon( filename, group, IconSize(KIconLoader::Toolbar) );
 }
 
 
@@ -698,9 +709,16 @@ QPixmap MDWSlider::loadIcon( QString filename )
 //	setIcon(filename, *label);
 //}
 
+/**
+ * Loads the icon with the given iconName in size KIconLoader::Toolbar, and applies it to the label widget.
+ * The label must be either a QLabel or a QToolButton.
+ *
+ * @param label A QToolButton or a QToolButton that will hold the icon.
+ */
 void MDWSlider::setIcon( QString filename, QWidget* label )
 {
-	QPixmap miniDevPM = loadIcon( filename );
+	QPixmap miniDevPM = loadIcon( filename, KIconLoader::Small );
+//	QPixmap miniDevPM = loadIcon( filename, KIconLoader::Toolbar);
 	if ( !miniDevPM.isNull() )
 	{
 		if ( m_small )
@@ -713,7 +731,7 @@ void MDWSlider::setIcon( QString filename, QWidget* label )
 		} // small size
 		else
 		{
-			label->setMinimumSize(22,22);
+			label->setMinimumSize(IconSize(KIconLoader::Toolbar),IconSize(KIconLoader::Toolbar));
 		}
 		label->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 		
@@ -982,8 +1000,8 @@ void MDWSlider::setDisabled( bool hide )
 
 
 /**
- * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which hare handeled by the
- * KMixWindow class. So for 99.9% of all users, this methos is never called.
+ * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which are handled by the
+ * KMixWindow class. So for 99.9% of all users, this method is never called.
  */
 void MDWSlider::increaseVolume()
 {
@@ -1107,10 +1125,8 @@ void MDWSlider::updateInternal(Volume& vol, QList<QAbstractSlider *>& ref_slider
 	if( m_qcb != 0 )
 	{
 		bool oldBlockState = m_qcb->blockSignals( true );
-		if (m_mixdevice->isMuted())
-			m_qcb->setIcon( QIcon( loadIcon("audio-volume-muted") ) );
-		else
-			m_qcb->setIcon( QIcon( loadIcon("audio-volume-high") ) );
+		QString muteIcon = m_mixdevice->isMuted() ? "audio-volume-muted" : "audio-volume-high";
+		setIcon(muteIcon, m_qcb);
 		m_qcb->blockSignals( oldBlockState );
 	}
 
@@ -1187,9 +1203,9 @@ void MDWSlider::showContextMenu( const QPoint& pos )
 		}
 	}
 
-	QAction *a = _mdwActions->action(  "hide" );
-	if ( a )
-		menu->addAction( a );
+//	QAction *a = _mdwActions->action(  "hide" );
+//	if ( a )
+//		menu->addAction( a );
 
 	QAction *b = _mdwActions->action( "keys" );
 	if ( b ) {
